@@ -8,6 +8,7 @@ __all__ = (
     'DateTimeField',
     'DecimalField',
     'FragmentField',
+    'FragmentWithNewlineField',
     'ListField',
 )
 
@@ -227,6 +228,15 @@ class FragmentField(FixedWidthField):
         return val.to_record()
 
 
+class FragmentWithNewlineField(FragmentField):
+
+    def to_record(self, val):
+        self.length += 1
+        if val is None:
+            return self.record_class().to_record() + '\n'
+        return val.to_record() + '\n'
+
+
 class ListField(FixedWidthField):
     """
     ListField allows you to have a field made up of a number of
