@@ -16,6 +16,7 @@ __all__ = (
     'DateTimeFieldTests',
     'ListFieldTests',
     'FragmentFieldTests',
+    'FragmentWithNewlineFieldTests',
 )
 
 class RecordOne(fixedwidth.Record):
@@ -32,6 +33,10 @@ class RecordThree(fixedwidth.Record):
     frag = fields.FragmentField(record=RecordOne)
     other_field = fields.StringField(length=3, default="BBB")
 
+class RecordFour(fixedwidth.Record):
+    frag = fields.FragmentWithNewlineField(record=RecordOne)
+    other_field = fields.StringField(length=3, default="EEE")
+
 
 class PaddingTests(TestCase):
 
@@ -458,8 +463,54 @@ class DateFieldTests(TestCase):
         self.assertEqual(date(2000, 1, 1), c.field_one)
 
 
+class FragmentWithNewlineFieldTests(TestCase):
+
+    def test_is_subclass_of_fragment_field(self):
+        self.assertTrue(issubclass(fields.FragmentWithNewlineField, fields.FragmentField))
+
+    def test_to_python_returns_record_instance_when_given_string(self):
+        f = fields.FragmentWithNewlineField(record=RecordOne)
+        python_val = f.to_python('AAAAA1111111')
+        self.assertIsInstance(python_val, RecordOne)
+
+    def test_to_record_returns_record_class_defaults_when_value_is_None(self):
+        f = fields.FragmentWithNewlineField(record=RecordOne)
+        self.assertEqual("AA   0000000\n", f.to_record(None))
+
+    def test_to_record_will_modify_the_length_by_one_to_account_for_newline(self):
+        my_record = RecordOne(field_one="aa", field_two=999)
+        r = RecordFour(frag=my_record, other_field="ZZZ")
+        self.assertEqual(16, len(str(r)))
+
+    def test_to_record_returns_string_of_record_when_has_explicit_values(self):
+        my_record = RecordOne(field_one="aa", field_two=999)
+        r = RecordFour(frag=my_record, other_field="ZZZ")
+        self.assertEqual("aa   0000999\nZZZ", r.to_record())
+
+    def test_to_record_returns_string_of_record_when_explicitly_set(self):
+        r = RecordFour(other_field="ZZZ")
+        self.assertEqual("AA   0000000\nZZZ", r.to_record())
+
+    def test_creates_record_object_properly_from_string(self):
+        r = RecordFour.from_record("aaaaa9999999ZZZ")
+        self.assertEqual("aaaaa", r.frag.field_one)
+        self.assertEqual(9999999, r.frag.field_two)
+        self.assertEqual("ZZZ", r.other_field)
+        self.assertIsInstance(r.frag, RecordOne)
+
+    def test_creates_record_object_properly_from_string_with_multiple_values(self):
+        r = RecordFour()
+        r.frag.field_one = "aaa"
+        r.frag.field_two = 999
+
+        self.assertEqual("aaa  0000999\nEEE", r.to_record())
+
 class FragmentFieldTests(TestCase):
 
+    def test_to_record_returns_record_class_defaults_when_value_is_None(self):
+        field = fields.FragmentField(record=RecordOne)
+        self.assertEqual("AA   0000000", field.to_record(None))
+
     def test_to_python_returns_record_instance_when_none_given(self):
         f = fields.FragmentField(record=RecordOne)
         python_val = f.to_python(None)
@@ -493,12 +544,12 @@ class FragmentFieldTests(TestCase):
 
     def test_creates_record_object_properly_from_string(self):
         r = RecordThree.from_record("aaaaa9999999ZZZ")
-        self.assertEqual("aaaaa", r.sub_field.field_one)
-        self.assertEqual(9999999, r.sub_field.field_two)
+        self.assertEqual("aaaaa", r.frag.field_one)
+        self.assertEqual(9999999, r.frag.field_two)
         self.assertEqual("ZZZ", r.other_field)
-        self.assertIsInstance(r.sub_field, RecordOne)
+        self.assertIsInstance(r.frag, RecordOne)
 
-    def test_creates_record_object_properly_from_string(self):
+    def test_creates_record_object_properly_from_string_with_multiple_values(self):
         r = RecordThree()
         r.frag.field_one = "aaa"
         r.frag.field_two = 999
